This is a tool help convert nsf music to midi

1. please install famistudio and put it into enviroment PATH
2. pip install nsf2midi
3. python -m nsf2midi input.nsf output.midi 0

for details please run
python -m nsf2midi -h